Takes in the geodesic distances, targets, avoiders, a parameter that prioritizes avoiding vs targetting, and the current players and returns the strategic players distance metric
distance(gd, targets, avoiders, theta, players)returns the distance metric for strategic players, which we want to maximize
a matrix of geodesic distances for the network of interest
a vector of indicies of the people you want to spread the intervention to
a vector of indicies of the people you don't want to spread the intervention to
a number between 0 and 1 which weights the distance metric, 1 only prioritizes closeness to targets, 0 only prioritizes maximizing distance from avoiders
the indicies of people who you have chosen for the intervention (a subset of targets)