Takes in the number of intervention subjects you wish to identify, geodesic distances, targets, avoiders, and a parameter that prioritizes avoiding vs targetting, and returns the indecies of the strategic players
sp(n.players, gd, targets, avoiders, theta = 0.5, n.loops = 1000)returns the indicies for strategic players
the number of intervention subjects you wish to identify
a matrix of geodesic distances for the network of interest
a vector of indicies of the people you want to spread the intervention to
a vector of indicies of the people you don't want to spread the intervention to
a number between 0 and 1 which weights the distance metric, 1 only prioritizes closeness to targets, 0 only prioritizes maximizing distance from avoiders. Any number between 0 and 1 will be a compromise of these two goals.
the number of loops to run, the more loops you run the more likely you are to identify the optimal set of strategic players